Documentation
¶
Index ¶
- type Stager
- func (s *Stager) GetETA() string
- func (s *Stager) GetLowWatermark() (string, error)
- func (s *Stager) GetProgress() string
- func (s *Stager) HasClearEstimates() bool
- func (s *Stager) RetryableStageChunk(ctx context.Context, chunk *table.Chunk) error
- func (s *Stager) RowsPerSecond() uint64
- func (s *Stager) SetThrottler(throttler throttler.Throttler)
- func (s *Stager) Stage(ctx context.Context) error
- func (s *Stager) StartTime() time.Time
- type StagerConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Stager ¶
type Stager struct {
sync.Mutex
StagedRowsCount uint64 // used for estimates: the exact number of rows staged
StagedChunksCount uint64
ChunkerOpen atomic.Bool
Throttler throttler.Throttler
// contains filtered or unexported fields
}
func NewStager ¶
func NewStager(sconfig *StagerConfig, chk *audit.Checkpoint) (*Stager, error)
NewStager creates a new stager, from a checkpoint (copyRowsAt, copyRows).
func (*Stager) GetLowWatermark ¶
GetLowWatermark returns the low watermark of the chunker, i.e. the lowest key that has been guaranteed to be written to the staging table.
func (*Stager) GetProgress ¶
GetProgress returns the progress of the stager.
func (*Stager) HasClearEstimates ¶
func (*Stager) RetryableStageChunk ¶
RetryableStageChunk copies the chunk to staging table, compares checksum between staging and source table and deletes chunk from source table, retrying the process until it succeeds or runs out of max configured retries.
func (*Stager) RowsPerSecond ¶
func (*Stager) SetThrottler ¶
Click to show internal directories.
Click to hide internal directories.